==> ToolChain_STM32_1.0.51.tar.bz: ToolChain_STM32_1.0.51/CommonLibraries/cm3/cm3_mutex.h <==
#ifndef cm3_mutex_H
#define cm3_mutex_H

/*{ cm3_mutex.h ***********************************************
 * 
 * Written by Gregor Rebel 2010-2012
 *
 * Low-level driver for Mutual Exclusive Locks (Mutexes) on Cortex M3 architecture.
 * 
}*/

//{ includes

#include "ttc_basic.h"
#include "ttc_mutex_types.h"
#include "cm3_basic.h"
#include "core_cm3.h"

//}includes
//{ Default settings (change via makefile) ******************************


//}Default settings
//{ Types & Structures ***************************************************


//}
//{ Low-Level driver macros for ttc_mutex.h ******************************

#define DRIVER_ttc_mutex_create()               cm3_mutex_create()
#define DRIVER_ttc_mutex_init(Mutex)            cm3_mutex_init(Mutex)
#define DRIVER_ttc_mutex_lock(Mutex, TimeOut)   cm3_mutex_lock(Mutex, TimeOut)
#define DRIVER_ttc_mutex_lock_isr(Mutex)        cm3_mutex_trylock(Mutex)
#define DRIVER_ttc_mutex_unlock(Mutex)          cm3_mutex_unlock(Mutex)
#define DRIVER_ttc_mutex_unlock_isr(Mutex)      cm3_mutex_unlock(Mutex)

// datatype used to store individual mutex
typedef u8_t cm3_Mutex;
#define ttc_Mutex unsigned char

//}
//{ includes 2 ***********************************************************

// these includes require macros and types above
#include "ttc_memory.h"

//}includes 2
//{ Function prototypes **************************************************


/** allocates + initializes a new non-recursive mutex lock
 * @return                 =! NULL: mutex has been created successfully (use handle to operate on mutex)
 */
cm3_Mutex* cm3_mutex_create();

/** initializes an existing non-recursive mutex lock to the unlocked state
 * @Lock                 storage to be initialized as mutex
 */
void cm3_mutex_init(cm3_Mutex* Lock);

/** Tries to obtain lock on mutex within timeout
 * @param Mutex  handle of already created mutex
 * @param TimeOut  !=-1: amount of system ticks to wait for lock
 *                 ==-1: wait forever
 * @return         == tme_OK: Lock has been successfully obtained within TimeOut
 */
ttc_mutex_error_e cm3_mutex_lock(cm3_Mutex* Mutex, Base_t TimeOut);

/** Tries to obtain lock on mutex; this function will never block
 * @param Mutex                handle of already created mutex
 * @return         == tme_OK: Lock has been successfully obtained within TimeOut
 *                 == tme_HigherPriorityTaskWoken: - a task of higher priority has been interrupted => call cm3_task_yield() at end of your interrupt service routine!
 *                 >= tme_Error: Error condition
 */
ttc_mutex_error_e cm3_mutex_trylock(cm3_Mutex* Mutex);

/** Releases an already obtained lock from mutex
 * @param Mutex  handle of already created smart mutex
 * @return         == tme_OK: Lock has been released successfully
 */
ttc_mutex_error_e cm3_mutex_unlock(cm3_Mutex* Mutex);


/** called while waiting for mutex lock. Place your breakpoint inside to debug hanging locks
  */
void cm3_mutex_wait();

//}Function prototypes

#endif

==> ToolChain_STM32_1.0.52.tar.bz: ToolChain_STM32_1.0.52/CommonLibraries/cm3/cm3_mutex.h <==
#ifndef cm3_mutex_H
#define cm3_mutex_H

/*{ cm3_mutex.h ***********************************************
 * 
 * Written by Gregor Rebel 2010-2012
 *
 * Low-level driver for Mutual Exclusive Locks (Mutexes) on Cortex M3 architecture.
 * 
}*/

//{ includes

#include "ttc_basic.h"
#include "cm3_basic.h"
#include "core_cm3.h"

//}includes
//{ Default settings (change via makefile) ******************************


//}Default settings
//{ Types & Structures ***************************************************


//}
//{ Low-Level driver macros for ttc_mutex.h ******************************

#define DRIVER_ttc_mutex_create()               cm3_mutex_create()
#define DRIVER_ttc_mutex_init(Mutex)            cm3_mutex_init(Mutex)
#define DRIVER_ttc_mutex_lock(Mutex, TimeOut)   cm3_mutex_lock(Mutex, TimeOut)
#define DRIVER_ttc_mutex_lock_isr(Mutex)        cm3_mutex_trylock_isr(Mutex)
#define DRIVER_ttc_mutex_is_locked(Mutex)       cm3_mutex_is_locked(Mutex)
#define DRIVER_ttc_mutex_unlock(Mutex)          cm3_mutex_unlock(Mutex)
#define DRIVER_ttc_mutex_unlock_isr(Mutex)      cm3_mutex_unlock(Mutex)


//}
//{ includes 2 ***********************************************************

// these includes require macros and types above
#include "cm3_mutex_types.h"
#include "ttc_mutex_types.h"
#include "ttc_memory.h"

//}includes 2
//{ Function prototypes **************************************************


/** allocates + initializes a new non-recursive mutex lock
 * @return                 =! NULL: mutex has been created successfully (use handle to operate on mutex)
 */
cm3_Mutex* cm3_mutex_create();

/** initializes an existing non-recursive mutex lock to the unlocked state
 * @Lock                 storage to be initialized as mutex
 */
void cm3_mutex_init(cm3_Mutex* Lock);

/** Tries to obtain lock on mutex within timeout
 * @param Mutex  handle of already created mutex
 * @param TimeOut  !=-1: amount of system ticks to wait for lock
 *                 ==-1: wait forever
 * @return         == tme_OK: Lock has been successfully obtained within TimeOut
 */
ttc_mutex_error_e cm3_mutex_lock(cm3_Mutex* Mutex, Base_t TimeOut);

/** Tries to obtain lock on mutex; this function will never block
 * @param Mutex                handle of already created mutex
 * @return         == tme_OK: Lock has been successfully obtained within TimeOut
 *                 == tme_WasLockedByTask: - a task of higher priority has been interrupted => call cm3_task_yield() at end of your interrupt service routine!
 *                 >= tme_Error: Error condition
 */
ttc_mutex_error_e cm3_mutex_trylock(cm3_Mutex* Mutex);

/** Tries to obtain lock on mutex; this function will never block (only to be called by interrupt service routines!)
 * @param Mutex    handle of already created mutex
 * @return         == tme_OK: Lock has been successfully obtained within TimeOut
 *                 == tme_WasLockedByTask: - a task of higher priority has been interrupted => call cm3_task_yield() at end of your interrupt service routine!
 *                 >= tme_Error: Error condition
 */
ttc_mutex_error_e cm3_mutex_trylock_isr(cm3_Mutex* Mutex);
#define cm3_mutex_trylock_isr(Mutex) cm3_mutex_trylock(Mutex)

/** Checks if given Mutex is currently locked
 * @param Mutex    handle of already created mutex
 * @return         == TRUE: given Mutex is currently in locked state; FALSE otherwise
 */
// BOOL cm3_mutex_is_locked(cm3_Mutex* Mutex);
#define cm3_mutex_is_locked(Mutex) (Mutex && (*Mutex != 0))

/** Releases an already obtained lock from mutex
 * @param Mutex  handle of already created smart mutex
 * @return         == tme_OK: Lock has been released successfully
 */
ttc_mutex_error_e cm3_mutex_unlock(cm3_Mutex* Mutex);

//}Function prototypes

#endif
